@@ -26,6 +26,11 @@
  *
  *
  * $Log: shpdata.c,v $
+ * Revision 1.3  2016-12-05 12:44:07  erouault
+ * * Major overhaul of Makefile build system to use autoconf/automake.
+ *
+ * * Warning fixes in contrib/
+ *
  * Revision 1.2  1999-05-26 02:56:31  candrsn
  * updates to shpdxf, dbfinfo, port from Shapelib 1.1.5 of dbfcat and shpinfo
  *
@@ -33,7 +38,7 @@
  * 
  */
       
-
+#include <stdlib.h>
 #include "shapefil.h"
 #include "shpgeo.h"
 
